package com.agilecontrol.nea.core.web.shell;

import com.agilecontrol.config.Resources;
import com.agilecontrol.nea.core.control.web.WebUtils;
import com.agilecontrol.nea.core.query.QueryUtils;
import com.agilecontrol.nea.core.query.web.TableQueryModel;
import com.agilecontrol.nea.core.schema.ClientManager;
import com.agilecontrol.nea.core.schema.Column;
import com.agilecontrol.nea.core.schema.Database;
import com.agilecontrol.nea.core.schema.SubSystem;
import com.agilecontrol.nea.core.schema.Table;
import com.agilecontrol.nea.core.schema.TableCategory;
import com.agilecontrol.nea.core.schema.TableManager;
import com.agilecontrol.nea.core.util.ConfigValues;
import com.agilecontrol.nea.core.util.ReleaseInfo;
import com.agilecontrol.nea.core.web.shell.AbstractShellCmd;
import com.agilecontrol.nea.core.web.shell.Shell;
import com.agilecontrol.nea.util.PairTable;
import com.agilecontrol.nea.util.Tools;
import java.io.File;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import java.util.Vector;
import org.apache.commons.lang3.StringUtils;
import org.json.JSONObject;
import org.thymeleaf.TemplateEngine;
import org.thymeleaf.context.Context;

@Shell(
   alias = "schemaview",
   admin = true,
   help = "schemaview 生成元数据的HTML完整定义"
)
public class SchemaView extends AbstractShellCmd {

   protected JSONObject process(String args, JSONObject envObj) throws Exception {
      String outputFolder = ConfigValues.DIR_NEA_ROOT + File.separator + "home" + File.separator + ClientManager.getInstance().getDefaultClient().getDomain() + File.separator + this.userWeb.getUserId();
      if(!(new File(outputFolder)).exists()) {
         (new File(outputFolder)).mkdirs();
      }

      String content = this.tableViewHtmlConstruct();
      Tools.writeFile(outputFolder + File.separator + "schemaview.html", content, "UTF-8");
      JSONObject json = new JSONObject();
      json.put("fileurl", WebUtils.getServletContext().getContextPath() + "/servlets/binserv/GetFile?filename=schemaview.html");
      json.put("target", "_blank");
      json.put("code", 0);
      return json;
   }

   private String tableViewHtmlConstruct() {
      Locale locale = TableManager.getDefaultSysLocale();
      Context context = new Context();
      TableManager manager = TableManager.getInstance();
      ArrayList subsystems = manager.getSubSystems();
      SubSystem subsystem = null;
      ArrayList tableContents = new ArrayList();

      for(int tableVector = 0; tableVector < subsystems.size(); ++tableVector) {
         subsystem = (SubSystem)subsystems.get(tableVector);
         String tableItems = subsystem.getDescription(locale);
         List tabcategorylist = subsystem.getTableCategories();
         SchemaView.TableContent tableContent = new SchemaView.TableContent();
         tableContent.setSubsystemDescription(tableItems == null?"":tableItems);
         tableContents.add(tableContent);

         for(int tableItem = 0; tableItem < tabcategorylist.size(); ++tableItem) {
            TableCategory columnItem = (TableCategory)tabcategorylist.get(tableItem);
            String templateEngine = columnItem.getDescription(locale);
            List tableOne = columnItem.getTables();
            tableContent = new SchemaView.TableContent();
            tableContent.setTableCategoryDescription(templateEngine == null?"":templateEngine);
            tableContents.add(tableContent);

            for(int allColumns = 0; allColumns < tableOne.size(); ++allColumns) {
               tableContent = new SchemaView.TableContent();
               Table columnItems = (Table)tableOne.get(allColumns);
               tableContent.setTableIdStr(columnItems.getId() + "");
               tableContent.setTableName(columnItems.getName() == null?"":columnItems.getName());
               tableContent.setTableDescription(columnItems.getDescription(locale) == null?"":columnItems.getDescription(locale));
               tableContents.add(tableContent);
            }
         }
      }

      context.setVariable("creationTime", ((SimpleDateFormat)QueryUtils.dateTimeSecondDashFormatter.get()).format(new Date()));
      context.setVariable("tableContents", tableContents);
      context.setVariable("schema", Database.getInstance().getLocalThreadSchema());
      context.setVariable("version", ReleaseInfo.getVersion());
      Vector var22 = (Vector)manager.getAllTables();
      ArrayList var23 = new ArrayList();
      Iterator var26 = var22.iterator();

      while(var26.hasNext()) {
         Table var28 = (Table)var26.next();
         SchemaView.TableItem var24 = new SchemaView.TableItem();
         var24.setTable(var28);
         var24.setDescription(var28.getDescription(locale));
         var24.setCommentNullable(StringUtils.isEmpty(var28.getComment()));
         ArrayList var29 = new ArrayList();
         ArrayList var30 = var28.getAllColumns();

         SchemaView.ColumnItem var25;
         for(Iterator var18 = var30.iterator(); var18.hasNext(); var29.add(var25)) {
            Column column = (Column)var18.next();
            var25 = new SchemaView.ColumnItem();
            var25.setColumn(column);
            var25.setDescription(column.getDescription(locale));
            var25.setInputBoxIndicator(TableQueryModel.getInputBoxIndicator(column, "", locale));
            var25.setNullable(column.isNullable()?"是":"否");
            var25.setPairTable(column.getValues(locale));
            if(column.getReferenceTable() != null) {
               var25.setReferenceTableDescription(column.getReferenceTable().getDescription(locale));
            }

            if(var25.getPairTable() != null) {
               ArrayList pairTableIndexList = new ArrayList();

               for(int i = 0; i < var25.getPairTable().size(); ++i) {
                  pairTableIndexList.add(Integer.valueOf(i));
               }

               var25.setPairTableIndexList(pairTableIndexList);
            }
         }

         var24.setColumnItems(var29);
         var23.add(var24);
      }

      context.setVariable("tableItems", var23);
      TemplateEngine var27 = (TemplateEngine)Resources.getBean("templateEngine");
      return var27.process("tableview", context);
   }

   static class TableContent {

      private String subsystemDescription;
      private String tableCategoryDescription;
      private String tableIdStr;
      private String tableName;
      private String tableDescription;


      public String getSubsystemDescription() {
         return this.subsystemDescription;
      }

      public String getTableCategoryDescription() {
         return this.tableCategoryDescription;
      }

      public String getTableIdStr() {
         return this.tableIdStr;
      }

      public String getTableName() {
         return this.tableName;
      }

      public String getTableDescription() {
         return this.tableDescription;
      }

      public void setSubsystemDescription(String subsystemDescription) {
         this.subsystemDescription = subsystemDescription;
      }

      public void setTableCategoryDescription(String tableCategoryDescription) {
         this.tableCategoryDescription = tableCategoryDescription;
      }

      public void setTableIdStr(String tableIdStr) {
         this.tableIdStr = tableIdStr;
      }

      public void setTableName(String tableName) {
         this.tableName = tableName;
      }

      public void setTableDescription(String tableDescription) {
         this.tableDescription = tableDescription;
      }

      public boolean equals(Object o) {
         if(o == this) {
            return true;
         } else if(!(o instanceof SchemaView.TableContent)) {
            return false;
         } else {
            SchemaView.TableContent other = (SchemaView.TableContent)o;
            if(!other.canEqual(this)) {
               return false;
            } else {
               label71: {
                  String this$subsystemDescription = this.getSubsystemDescription();
                  String other$subsystemDescription = other.getSubsystemDescription();
                  if(this$subsystemDescription == null) {
                     if(other$subsystemDescription == null) {
                        break label71;
                     }
                  } else if(this$subsystemDescription.equals(other$subsystemDescription)) {
                     break label71;
                  }

                  return false;
               }

               String this$tableCategoryDescription = this.getTableCategoryDescription();
               String other$tableCategoryDescription = other.getTableCategoryDescription();
               if(this$tableCategoryDescription == null) {
                  if(other$tableCategoryDescription != null) {
                     return false;
                  }
               } else if(!this$tableCategoryDescription.equals(other$tableCategoryDescription)) {
                  return false;
               }

               label57: {
                  String this$tableIdStr = this.getTableIdStr();
                  String other$tableIdStr = other.getTableIdStr();
                  if(this$tableIdStr == null) {
                     if(other$tableIdStr == null) {
                        break label57;
                     }
                  } else if(this$tableIdStr.equals(other$tableIdStr)) {
                     break label57;
                  }

                  return false;
               }

               String this$tableName = this.getTableName();
               String other$tableName = other.getTableName();
               if(this$tableName == null) {
                  if(other$tableName != null) {
                     return false;
                  }
               } else if(!this$tableName.equals(other$tableName)) {
                  return false;
               }

               String this$tableDescription = this.getTableDescription();
               String other$tableDescription = other.getTableDescription();
               if(this$tableDescription == null) {
                  if(other$tableDescription == null) {
                     return true;
                  }
               } else if(this$tableDescription.equals(other$tableDescription)) {
                  return true;
               }

               return false;
            }
         }
      }

      protected boolean canEqual(Object other) {
         return other instanceof SchemaView.TableContent;
      }

      public int hashCode() {
         boolean PRIME = true;
         byte result = 1;
         String $subsystemDescription = this.getSubsystemDescription();
         int result1 = result * 59 + ($subsystemDescription == null?43:$subsystemDescription.hashCode());
         String $tableCategoryDescription = this.getTableCategoryDescription();
         result1 = result1 * 59 + ($tableCategoryDescription == null?43:$tableCategoryDescription.hashCode());
         String $tableIdStr = this.getTableIdStr();
         result1 = result1 * 59 + ($tableIdStr == null?43:$tableIdStr.hashCode());
         String $tableName = this.getTableName();
         result1 = result1 * 59 + ($tableName == null?43:$tableName.hashCode());
         String $tableDescription = this.getTableDescription();
         result1 = result1 * 59 + ($tableDescription == null?43:$tableDescription.hashCode());
         return result1;
      }

      public String toString() {
         return "SchemaView.TableContent(subsystemDescription=" + this.getSubsystemDescription() + ", tableCategoryDescription=" + this.getTableCategoryDescription() + ", tableIdStr=" + this.getTableIdStr() + ", tableName=" + this.getTableName() + ", tableDescription=" + this.getTableDescription() + ")";
      }
   }

   static class ColumnItem {

      public Column column;
      public String description;
      public String inputBoxIndicator;
      public String nullable;
      public PairTable pairTable;
      public List pairTableIndexList;
      public String referenceTableDescription;


      public Column getColumn() {
         return this.column;
      }

      public String getDescription() {
         return this.description;
      }

      public String getInputBoxIndicator() {
         return this.inputBoxIndicator;
      }

      public String getNullable() {
         return this.nullable;
      }

      public PairTable getPairTable() {
         return this.pairTable;
      }

      public List getPairTableIndexList() {
         return this.pairTableIndexList;
      }

      public String getReferenceTableDescription() {
         return this.referenceTableDescription;
      }

      public void setColumn(Column column) {
         this.column = column;
      }

      public void setDescription(String description) {
         this.description = description;
      }

      public void setInputBoxIndicator(String inputBoxIndicator) {
         this.inputBoxIndicator = inputBoxIndicator;
      }

      public void setNullable(String nullable) {
         this.nullable = nullable;
      }

      public void setPairTable(PairTable pairTable) {
         this.pairTable = pairTable;
      }

      public void setPairTableIndexList(List pairTableIndexList) {
         this.pairTableIndexList = pairTableIndexList;
      }

      public void setReferenceTableDescription(String referenceTableDescription) {
         this.referenceTableDescription = referenceTableDescription;
      }

      public boolean equals(Object o) {
         if(o == this) {
            return true;
         } else if(!(o instanceof SchemaView.ColumnItem)) {
            return false;
         } else {
            SchemaView.ColumnItem other = (SchemaView.ColumnItem)o;
            if(!other.canEqual(this)) {
               return false;
            } else {
               label95: {
                  Column this$column = this.getColumn();
                  Column other$column = other.getColumn();
                  if(this$column == null) {
                     if(other$column == null) {
                        break label95;
                     }
                  } else if(this$column.equals(other$column)) {
                     break label95;
                  }

                  return false;
               }

               String this$description = this.getDescription();
               String other$description = other.getDescription();
               if(this$description == null) {
                  if(other$description != null) {
                     return false;
                  }
               } else if(!this$description.equals(other$description)) {
                  return false;
               }

               String this$inputBoxIndicator = this.getInputBoxIndicator();
               String other$inputBoxIndicator = other.getInputBoxIndicator();
               if(this$inputBoxIndicator == null) {
                  if(other$inputBoxIndicator != null) {
                     return false;
                  }
               } else if(!this$inputBoxIndicator.equals(other$inputBoxIndicator)) {
                  return false;
               }

               label74: {
                  String this$nullable = this.getNullable();
                  String other$nullable = other.getNullable();
                  if(this$nullable == null) {
                     if(other$nullable == null) {
                        break label74;
                     }
                  } else if(this$nullable.equals(other$nullable)) {
                     break label74;
                  }

                  return false;
               }

               label67: {
                  PairTable this$pairTable = this.getPairTable();
                  PairTable other$pairTable = other.getPairTable();
                  if(this$pairTable == null) {
                     if(other$pairTable == null) {
                        break label67;
                     }
                  } else if(this$pairTable.equals(other$pairTable)) {
                     break label67;
                  }

                  return false;
               }

               List this$pairTableIndexList = this.getPairTableIndexList();
               List other$pairTableIndexList = other.getPairTableIndexList();
               if(this$pairTableIndexList == null) {
                  if(other$pairTableIndexList != null) {
                     return false;
                  }
               } else if(!this$pairTableIndexList.equals(other$pairTableIndexList)) {
                  return false;
               }

               String this$referenceTableDescription = this.getReferenceTableDescription();
               String other$referenceTableDescription = other.getReferenceTableDescription();
               if(this$referenceTableDescription == null) {
                  if(other$referenceTableDescription != null) {
                     return false;
                  }
               } else if(!this$referenceTableDescription.equals(other$referenceTableDescription)) {
                  return false;
               }

               return true;
            }
         }
      }

      protected boolean canEqual(Object other) {
         return other instanceof SchemaView.ColumnItem;
      }

      public int hashCode() {
         boolean PRIME = true;
         byte result = 1;
         Column $column = this.getColumn();
         int result1 = result * 59 + ($column == null?43:$column.hashCode());
         String $description = this.getDescription();
         result1 = result1 * 59 + ($description == null?43:$description.hashCode());
         String $inputBoxIndicator = this.getInputBoxIndicator();
         result1 = result1 * 59 + ($inputBoxIndicator == null?43:$inputBoxIndicator.hashCode());
         String $nullable = this.getNullable();
         result1 = result1 * 59 + ($nullable == null?43:$nullable.hashCode());
         PairTable $pairTable = this.getPairTable();
         result1 = result1 * 59 + ($pairTable == null?43:$pairTable.hashCode());
         List $pairTableIndexList = this.getPairTableIndexList();
         result1 = result1 * 59 + ($pairTableIndexList == null?43:$pairTableIndexList.hashCode());
         String $referenceTableDescription = this.getReferenceTableDescription();
         result1 = result1 * 59 + ($referenceTableDescription == null?43:$referenceTableDescription.hashCode());
         return result1;
      }

      public String toString() {
         return "SchemaView.ColumnItem(column=" + this.getColumn() + ", description=" + this.getDescription() + ", inputBoxIndicator=" + this.getInputBoxIndicator() + ", nullable=" + this.getNullable() + ", pairTable=" + this.getPairTable() + ", pairTableIndexList=" + this.getPairTableIndexList() + ", referenceTableDescription=" + this.getReferenceTableDescription() + ")";
      }
   }

   static class TableItem {

      private Table table;
      List columnItems;
      private String description;
      private boolean commentNullable;


      public boolean getCommentNullable() {
         return this.commentNullable;
      }

      public Table getTable() {
         return this.table;
      }

      public List getColumnItems() {
         return this.columnItems;
      }

      public String getDescription() {
         return this.description;
      }

      public void setTable(Table table) {
         this.table = table;
      }

      public void setColumnItems(List columnItems) {
         this.columnItems = columnItems;
      }

      public void setDescription(String description) {
         this.description = description;
      }

      public void setCommentNullable(boolean commentNullable) {
         this.commentNullable = commentNullable;
      }

      public boolean equals(Object o) {
         if(o == this) {
            return true;
         } else if(!(o instanceof SchemaView.TableItem)) {
            return false;
         } else {
            SchemaView.TableItem other = (SchemaView.TableItem)o;
            if(!other.canEqual(this)) {
               return false;
            } else {
               Table this$table = this.getTable();
               Table other$table = other.getTable();
               if(this$table == null) {
                  if(other$table != null) {
                     return false;
                  }
               } else if(!this$table.equals(other$table)) {
                  return false;
               }

               List this$columnItems = this.getColumnItems();
               List other$columnItems = other.getColumnItems();
               if(this$columnItems == null) {
                  if(other$columnItems != null) {
                     return false;
                  }
               } else if(!this$columnItems.equals(other$columnItems)) {
                  return false;
               }

               String this$description = this.getDescription();
               String other$description = other.getDescription();
               if(this$description == null) {
                  if(other$description != null) {
                     return false;
                  }
               } else if(!this$description.equals(other$description)) {
                  return false;
               }

               if(this.getCommentNullable() != other.getCommentNullable()) {
                  return false;
               } else {
                  return true;
               }
            }
         }
      }

      protected boolean canEqual(Object other) {
         return other instanceof SchemaView.TableItem;
      }

      public int hashCode() {
         boolean PRIME = true;
         byte result = 1;
         Table $table = this.getTable();
         int result1 = result * 59 + ($table == null?43:$table.hashCode());
         List $columnItems = this.getColumnItems();
         result1 = result1 * 59 + ($columnItems == null?43:$columnItems.hashCode());
         String $description = this.getDescription();
         result1 = result1 * 59 + ($description == null?43:$description.hashCode());
         result1 = result1 * 59 + (this.getCommentNullable()?79:97);
         return result1;
      }

      public String toString() {
         return "SchemaView.TableItem(table=" + this.getTable() + ", columnItems=" + this.getColumnItems() + ", description=" + this.getDescription() + ", commentNullable=" + this.getCommentNullable() + ")";
      }
   }
}
